package com.ynet.life.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.LifeFile;
import com.ynet.life.file.parser.CommonFileParserInterface;
import com.ynet.life.file.parser.CommonParserFactory;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Random;
import java.util.StringTokenizer;

/* loaded from: com_ynet_life_action.jar:com/ynet/life/action/PublicDownloadWithConditionsAction.class */
public class PublicDownloadWithConditionsAction extends LifeAction {
    protected static final String FIELD_SEPERATOR = "||";
    protected String fileTypeField;
    protected String encoding;
    protected List outputFields;
    protected List outputFormats;
    protected List titles;
    protected String iCollName;
    protected String conditionFields;

    public String execute(Context ctx) throws GENEException {
        ctx.terminate();
        List recordList = initFromContext(ctx, this.iCollName);
        String fileType = (String) ctx.get(this.fileTypeField);
        CommonFileParserInterface parser = CommonParserFactory.createParser(fileType);
        String filePathName = getFileName(fileType);
        String language = getLanguage(ctx);
        List titlesI18N = new ArrayList();
        String condition = (String) ctx.get(this.conditionFields);
        List<String> conditionList = new ArrayList<>();
        StringTokenizer toke = new StringTokenizer(condition, ",");
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            conditionList.add(input);
        }
        List<String> titlesI18NBak = new ArrayList<>();
        List<Map> recordListBak = new ArrayList<>();
        List<String> outputFieldsBak = new ArrayList<>();
        List<String> outputFormatsBak = new ArrayList<>();
        if (this.titles != null) {
            for (int i = 0; i < this.titles.size(); i++) {
                titlesI18N.add(LifeStandard.getResouceDisplayAt((String) this.titles.get(i), language));
            }
        }
        for (int j = 0; j < conditionList.size(); j++) {
            int index = this.outputFields.indexOf(conditionList.get(j));
            titlesI18NBak.add((String) titlesI18N.get(index));
            outputFieldsBak.add((String) this.outputFields.get(index));
            outputFormatsBak.add((String) this.outputFormats.get(index));
        }
        for (int i2 = 0; i2 < recordList.size(); i2++) {
            Map map1 = (Map) recordList.get(i2);
            Map map = new HashMap();
            for (int j2 = 0; j2 < conditionList.size(); j2++) {
                String dataName = conditionList.get(j2);
                map.put(dataName, map1.get(dataName));
            }
            recordListBak.add(map);
        }
        parser.writeToFile(titlesI18NBak, recordListBak, outputFieldsBak, outputFormatsBak, filePathName, this.encoding);
        ctx.put("downloadFile", filePathName);
        return "0";
    }

    protected String getLanguage(Context context) {
        if (context == null) {
            return null;
        }
        String language = null;
        try {
            language = (String) context.getDataValue("session_language");
        } catch (GENEException unused) {
        }
        return language;
    }

    protected String getFileName(String fileType) throws TranFailException {
        String rootPath = LifeStandard.getSelfDefineSettingsValue("tempDownloadDir");
        String folder = String.valueOf(LifeStandard.getServerTime("yyyyMMdd")) + LifeFile.DIR_SEPARATOR;
        LifeFile.makeMultiDirectory(rootPath, folder);
        String fileName = String.valueOf(LifeStandard.getServerTime("HHmmssSSS")) + new Random().nextInt(1000) + '.' + fileType;
        return String.valueOf(rootPath) + folder + fileName;
    }

    public List initFromContext(Map context, String iCollName) throws TranFailException {
        List recordList = new ArrayList();
        for (Map kcoll : (List) context.get(iCollName)) {
            recordList.add(kcoll);
        }
        return recordList;
    }

    public void setOutputFields(String outputFields) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(outputFields, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.outputFields = result;
    }

    public void setOutputFormats(String outputFormats) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(outputFormats, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.outputFormats = result;
    }

    public void setTitles(String titles) {
        List title = new ArrayList();
        StringTokenizer toke = new StringTokenizer(titles, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            title.add(input);
        }
        this.titles = title;
    }

    public void setICollName(String collName) {
        this.iCollName = collName;
    }

    public void setFileTypeField(String fileTypeField) {
        this.fileTypeField = fileTypeField;
    }

    public void setEncoding(String encoding) {
        this.encoding = encoding;
    }

    public void setConditionFields(String conditionFields) {
        this.conditionFields = conditionFields;
    }
}
